# This file was auto-generated by Fern from our API Definition.

import datetime as dt
import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .dashboard_public_scope import DashboardPublicScope
from .dashboard_public_type import DashboardPublicType
from .json_node_public import JsonNodePublic


class DashboardPublic(UniversalBaseModel):
    id: typing.Optional[str] = None
    workspace_id: typing.Optional[str] = None
    name: str
    slug: typing.Optional[str] = None
    type: typing.Optional[DashboardPublicType] = None
    scope: typing.Optional[DashboardPublicScope] = None
    description: typing.Optional[str] = None
    config: JsonNodePublic
    created_by: typing.Optional[str] = None
    last_updated_by: typing.Optional[str] = None
    created_at: typing.Optional[dt.datetime] = None
    last_updated_at: typing.Optional[dt.datetime] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
