# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .param import Param


class Agent(UniversalBaseModel):
    name: typing.Optional[str] = None
    description: typing.Optional[str] = None
    language: typing.Optional[str] = None
    executable: typing.Optional[str] = None
    source_file: typing.Optional[str] = None
    params: typing.Optional[typing.List[Param]] = None
    timeout: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
